# $Id: td_make.in,v 12.30 2012/09/04 08:39:42 tom Exp $
# common definitions for makefiles built over TD_LIB library.
# vile:makemode

SHELL	= /bin/sh


####### (Environment) ##########################################################
prefix		= /usr
exec_prefix	= ${prefix}

bindir		= ${exec_prefix}/bin
libdir		= ${prefix}/lib
datarootdir	= ${prefix}/share
mandir		= ${prefix}/share/man
datadir		= ${datarootdir}

TD_LIB = /usr/lib
TD_INC = /usr/include/td

AR		= ar crv
RM		= rm -f
LINT		= alint
CTAGS		= ctags
ETAGS		= etags

CC		= x86_64-linux-gnu-gcc
CPP		= x86_64-linux-gnu-gcc -E
INSTALL		= /usr/bin/install -c
INSTALL_PROGRAM	= ${INSTALL}
INSTALL_DATA	= ${INSTALL} -m 644
RANLIB		= ranlib
MAKE_OPTS	= -${MAKEFLAGS}

EXTRA_CFLAGS	= 
CFLAGS		=  -O2
LINK		= $(CC) $(CFLAGS)

INSTALL_BIN	= $(DESTDIR)$(bindir)
INSTALL_INC	= $(DESTDIR)$(includedir)
INSTALL_LIB	= $(DESTDIR)$(libdir)
INSTALL_MAN	= $(DESTDIR)$(mandir)

####### (Command-line Options) #################################################
EXTRA_CPPFLAGS	= 
CPPFLAGS	=  -D_GNU_SOURCE -I/usr/include/ncursesw
CPP_CONFIG	= -I. -I$(TD_INC) -DHAVE_CONFIG_H $(CPPFLAGS) $(EXTRA_CPPFLAGS)
CPP_OPTS	= $(CPP_CONFIG) $(EXTRA_CPP_OPTS)

x		= 
LIB_DEPS	= $(TD_LIB)/libtd.a
LIB_ARGS	=  -L$(TD_LIB) -ltd 

CURSES_LIBS	=  -L$(TD_LIB) -ltd -L/usr/lib -lncursesw  

DATE		= echo '** '`date` >> $@

LINTLIBS	= -ltd 
LINTOPTS	= $(CPP_OPTS) -DNO_IDENT $(LINTLIBS)

####### (Standard Lists) #######################################################
# don't put .a into CLEAN, because VERDIX-ADA uses that for source!
CLEAN	= *.[oi] *.lint *.bak *.log *.out *.tst .nfs* *.pure* core tags
DESTROY	=$(SHELL) -c 'for i in *;do case $$i in RCS);; *) $(RM) $$i;;esac;done;exit 0'
RUN_TESTS=$(SHELL) -c './run_test.sh 2>&1 | tee -a $@.out'

PTYPES_H =	$(TD_INC)/ptypes.h \
		$(TD_INC)/td_ext.h \
		$(TD_INC)/td_lib.h \
		$(TD_INC)/td_config.h
CURSES_H =	$(PTYPES_H) \
		$(TD_INC)/td_curse.h
QSORT_H =	$(PTYPES_H) \
		$(TD_INC)/td_qsort.h
RCSDEFS_H =	$(PTYPES_H) \
		$(TD_INC)/rcsdefs.h \
		$(TD_INC)/deltree.h
SCCSDEFS_H =	$(PTYPES_H) \
		$(TD_INC)/sccsdefs.h

####### (Development) ##########################################################
CPROTO	= cproto -e -i -fo'\\n\\t\\t' -fp'\\n\\t\\t'

LINT_EACH = $(SHELL) -c 'for i in $?;do echo $$i:; $(LINT) $(LINTOPTS) $$i >>$@;done'

#.SUFFIXES:
.SUFFIXES: .c .o .a

.c.o:
	@echo compiling $<
	@$(CC) $(CPP_OPTS) $(CFLAGS) $(EXTRA_CFLAGS) -c $<
.o.a:
	@$(AR) $@ $*.o
	-@$(RM) $*.o
.c.a:
	@echo compiling $<
	@$(CC) $(CPP_OPTS) $(CFLAGS) $(EXTRA_CFLAGS) -c $<
	@$(AR) $@ $*.o
	-@$(RM) $*.o

.SUFFIXES: .i .proto .lint .tst

.c.i:		; $(CC) $(CPP_OPTS) -E -C $< >$@
.c.proto:	; $(CPROTO) $(CPP_OPTS) $< >$@
.c.lint:	; $(LINT) $(LINTOPTS) $< >$@

.c.tst:
	@echo linking $@;$(CC) -o $@ -DTEST $(CFLAGS) $(EXTRA_CFLAGS) $(CPP_OPTS) $< $Z $(LIB_ARGS)

CLEAN__MAN =  .cat  .pdf .ps .html .png .txt 

.SUFFIXES: .man .cat  .pdf .ps .html .txt 

NROFF	= /usr/bin/nroff

.man.cat:
	-$(RM) $@
	$(NROFF) -man $? >$@

GROFF	= /usr/bin/groff

.man.html :
	GROFF_NO_SGR=stupid $(SHELL) -c "tbl $*.man | $(GROFF) -Thtml -man" >$@

.man.ps :
	$(SHELL) -c "tbl $*.man | $(GROFF) -man" >$@

.man.txt :
	GROFF_NO_SGR=stupid $(SHELL) -c "tbl $*.man | $(GROFF) -Tascii -man | col -bx" >$@

.ps.pdf :
	ps2pdf $*.ps
